@@ -9,15 +9,15 @@
 
 #include "libkdebugsettingscore_private_export.h"
 #include <QDebug>
+#include <QList>
 #include <QString>
-#include <QVector>
 
 struct LIBKDEBUGSETTINGSCORE_EXPORT_TEST_EXPORT KdeLoggingCategory {
     KdeLoggingCategory();
-    using List = QVector<KdeLoggingCategory>;
-    Q_REQUIRED_RESULT bool operator==(const KdeLoggingCategory &other) const;
-    Q_REQUIRED_RESULT bool operator!=(const KdeLoggingCategory &other) const;
-    Q_REQUIRED_RESULT bool isValid() const;
+    using List = QList<KdeLoggingCategory>;
+    [[nodiscard]] bool operator==(const KdeLoggingCategory &other) const;
+    [[nodiscard]] bool operator!=(const KdeLoggingCategory &other) const;
+    [[nodiscard]] bool isValid() const;
 
     QString description;
     QString categoryName;
@@ -25,5 +25,5 @@ struct LIBKDEBUGSETTINGSCORE_EXPORT_TEST_EXPORT KdeLoggingCategory {
     QString defaultSeverity;
 };
 LIBKDEBUGSETTINGSCORE_EXPORT_TEST_EXPORT QDebug operator<<(QDebug debug, const KdeLoggingCategory &cat);
-Q_DECLARE_TYPEINFO(KdeLoggingCategory, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(KdeLoggingCategory, Q_RELOCATABLE_TYPE);
 Q_DECLARE_METATYPE(KdeLoggingCategory)
