@@ -19,12 +19,12 @@ public:
     explicit CategoryTypeModel(QObject *parent = nullptr);
     ~CategoryTypeModel() override;
 
-    Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent = QModelIndex()) const override;
-    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
-    Q_REQUIRED_RESULT QHash<int, QByteArray> roleNames() const override;
+    [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
 
-    Q_INVOKABLE Q_REQUIRED_RESULT int indexOfCategory(LoggingCategory::LoggingType type) const;
+    Q_INVOKABLE [[nodiscard]] int indexOfCategory(LoggingCategory::LoggingType type) const;
 
 private:
     struct CategoryInfo {
@@ -36,8 +36,8 @@ private:
         QString displayText;
         LoggingCategory::LoggingType type;
     };
-    Q_REQUIRED_RESULT CategoryTypeModel::CategoryInfo createCategoryInfo(LoggingCategory::LoggingType type);
+    [[nodiscard]] CategoryTypeModel::CategoryInfo createCategoryInfo(LoggingCategory::LoggingType type);
     void fillCategoryTypes();
-    QVector<CategoryInfo> mCategoryInfoList;
+    QList<CategoryInfo> mCategoryInfoList;
     QHash<int, QByteArray> mRoleNames;
 };
