@@ -7,19 +7,19 @@
 #pragma once
 
 #include "libkdebugsettingscore_private_export.h"
+#include <QList>
 #include <QObject>
 #include <QString>
-#include <QVector>
 struct LIBKDEBUGSETTINGSCORE_EXPORT_TEST_EXPORT RenameCategory {
 public:
     RenameCategory() = default;
 
-    using List = QVector<RenameCategory>;
-    Q_REQUIRED_RESULT bool operator==(const RenameCategory &other) const;
-    Q_REQUIRED_RESULT bool isValid() const;
+    using List = QList<RenameCategory>;
+    [[nodiscard]] bool operator==(const RenameCategory &other) const;
+    [[nodiscard]] bool isValid() const;
 
     QString originalName;
     QString newName;
 };
-Q_DECLARE_TYPEINFO(RenameCategory, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(RenameCategory, Q_RELOCATABLE_TYPE);
 Q_DECLARE_METATYPE(RenameCategory)
